DebugDisplay

Struct DebugDisplay 

pub struct DebugDisplay;
Available on crate feature debug-window only.
Entry point for the debug display system.

This struct provides the run() method, which takes over the main thread for the winit event loop and runs user code on a background thread.

Implementations

Source

impl DebugDisplay

pub fn run<F>(user_fn: F)
where F: FnOnce(&DisplayContext) + Send + 'static,

Run the debug display system.

Takes over the main thread for the winit event loop. The user’s code runs in the provided closure on a background thread, which receives a DisplayContext handle for displaying images.

The event loop exits when:

  • All windows are closed by the user, OR
  • The user closure returns (an Exit command is sent automatically).
Examples
use fovea_display::{DebugDisplay, AutoContrast, Identity};
use fovea::image::Image;
use fovea::pixel::Srgba8;

DebugDisplay::run(|ctx| {
    let img = Image::fill(640, 480, Srgba8::new(128, 64, 200, 255));
    ctx.show("Preview", &img, Identity);
    ctx.wait_key();
});
Panics

Panics if the event loop cannot be created (e.g. no display server available). On macOS, panics if called from a non-main thread.